@@ -8,6 +8,12 @@ INIT_SCRIPTS_DIR=/opt/debootstick/live/init
 # if error, run a shell
 trap '[ "$?" -eq 0 ] || fallback_sh' EXIT
 
+# we will need /proc and /sys
+[ -e /proc/self ] || mount_proc=1
+[ -e /sys/class ] || mount_sys=1
+[ "$mount_proc" = "1" ] && mount -t proc none /proc
+[ "$mount_sys" = "1" ] && mount -t sysfs none /sys
+
 # remount / read-write
 mount -o remount,rw /
 
@@ -32,6 +38,10 @@ fi
 # initial chroot environment
 restore_lvm_conf
 
+# cleanup
+[ "$mount_proc" = "1" ] && umount /proc
+[ "$mount_sys" = "1" ] && umount /sys
+
 # restore and start the usual init
 rm /sbin/init
 mv /sbin/init.orig /sbin/init
